@@ -9,7 +9,7 @@ import requests
 import yamale
 import yaml
 from betterboto import client as betterboto_client
-
+import networkx as nx
 from servicecatalog_puppet import asset_helpers
 from servicecatalog_puppet import config
 from servicecatalog_puppet import constants
@@ -192,6 +192,8 @@ def validate(f):
         manifest.get("defaults", {}).get("accounts", {}).get("regions_enabled", False)
     )
 
+    graph = nx.DiGraph()
+
     tags_defined_by_accounts = {}
     for account in manifest.get("accounts"):
         account_entry_is_an_overwrite_or_append = account.get(
@@ -248,25 +250,66 @@ def validate(f):
                     )
                     dd = depends_on.get("name")
                     if manifest.get(tt).get(dd) is None:
-                        print_utils.warn(f"{collection_type}.{collection_name} uses {depends_on} in depends_on that does not exist",)
+                        print_utils.warn(
+                            f"{collection_type}.{collection_name} uses {depends_on} in depends_on that does not exist",
+                        )
 
             #
             # Check depends_on is present when parameters names match outputs defined elsewhere
             #
-            for parameter_name, parameter_details in collection_item.get("parameters", {}).items():
+            for parameter_name, parameter_details in collection_item.get(
+                "parameters", {}
+            ).items():
                 if parameter_details.get("ssm"):
                     output_name = parameter_details.get("ssm").get("name")
-                    for needle_section_name in constants.ALL_SECTION_NAMES_THAT_GENERATE_OUTPUTS:
-                        for needle_action_name, needle_action_details in manifest.get(needle_section_name, {}).items():
-                            for needle_output in needle_action_details.get("outputs", {}).get("ssm", []):
+                    for (
+                        needle_section_name
+                    ) in constants.ALL_SECTION_NAMES_THAT_GENERATE_OUTPUTS:
+                        for needle_action_name, needle_action_details in manifest.get(
+                            needle_section_name, {}
+                        ).items():
+                            for needle_output in needle_action_details.get(
+                                "outputs", {}
+                            ).get("ssm", []):
                                 if output_name == needle_output.get("param_name"):
                                     found = False
-                                    for dependency in collection_item.get("depends_on", []):
-                                        plural = constants.SECTION_SINGULAR_TO_PLURAL.get(dependency.get("type", constants.LAUNCH))
-                                        if dependency.get("name") == needle_action_name and plural == needle_section_name:
+                                    for dependency in collection_item.get(
+                                        "depends_on", []
+                                    ):
+                                        plural = constants.SECTION_SINGULAR_TO_PLURAL.get(
+                                            dependency.get("type", constants.LAUNCH)
+                                        )
+                                        if (
+                                            dependency.get("name") == needle_action_name
+                                            and plural == needle_section_name
+                                        ):
                                             found = True
                                     if not found:
-                                        print_utils.error(f"{output_name} is used in {collection_type}.{collection_name} from {needle_section_name}.{needle_action_name} but is not in depends_on")
+                                        print_utils.error(
+                                            f"{output_name} is used in {collection_type}.{collection_name} from {needle_section_name}.{needle_action_name} but is not in depends_on"
+                                        )
+
+            #
+            # build graph to check for issues
+            #
+            uid = f"{collection_type}|{collection_name}"
+            data = collection_item
+            graph.add_nodes_from(
+                [(uid, data),]
+            )
+            for dependency in collection_item.get("depends_on", []):
+                plural = constants.SECTION_SINGULAR_TO_PLURAL.get(
+                    dependency.get("type", constants.LAUNCH)
+                )
+                duid = f"{plural}|{dependency.get('name')}"
+                graph.add_edge(uid, duid)
+    try:
+        cycle = nx.find_cycle(graph)
+        raise Exception(
+            f"found cyclic dependency in your manifest file between: {cycle}"
+        )
+    except nx.exception.NetworkXNoCycle:
+        pass
 
     print_utils.echo("Finished validating: {}".format(f.name))
     print_utils.echo("Finished validating: OK")
