@@ -1,19 +1,12 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#  SPDX-License-Identifier: Apache-2.0
-
 from unittest import skip
-
 from servicecatalog_puppet.workflow import tasks_unit_tests_helper
 
 
 class CreateSpokeLocalPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTest):
-    manifest_file_path = "manifest_file_path"
-    puppet_account_id = "puppet_account_id"
     account_id = "account_id"
     region = "region"
     portfolio = "portfolio"
-    organization = "organization"
-    sharing_mode = "sharing_mode"
+    portfolio_task_reference = "portfolio_task_reference"
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.portfolio.portfolio_management import (
@@ -23,13 +16,11 @@ class CreateSpokeLocalPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTe
         self.module = create_spoke_local_portfolio_task
 
         self.sut = self.module.CreateSpokeLocalPortfolioTask(
-            manifest_file_path=self.manifest_file_path,
-            puppet_account_id=self.puppet_account_id,
+            **self.get_common_args(),
             account_id=self.account_id,
             region=self.region,
             portfolio=self.portfolio,
-            organization=self.organization,
-            sharing_mode=self.sharing_mode,
+            portfolio_task_reference=self.portfolio_task_reference,
         )
 
         self.wire_up_mocks()
@@ -37,6 +28,7 @@ class CreateSpokeLocalPortfolioTaskTest(tasks_unit_tests_helper.PuppetTaskUnitTe
     def test_params_for_results_display(self):
         # setup
         expected_result = {
+            "task_reference": self.task_reference,
             "puppet_account_id": self.puppet_account_id,
             "portfolio": self.portfolio,
             "region": self.region,
